<script type="text/javascript">
    var _gaq = _gaq || [];
    _gaq.push(['_setAccount', '{{ code }}']);
    _gaq.push(['_trackPageview']);
    _gaq.push(['_trackPageLoadTime']);
    // _gaq.push(['_setCustomVar', 1, 'Authentication Type', ut, 2]);
    {% for action in actions %}
        _gaq.{{ action.method }}(
            {% for arg in action.args %}
                {{ arg|safe }}{% if forloop.last %}{% else %}, {% endif %}
            {% endfor %}
        );
    {% endfor %}
    
    (function() {
        var ga = document.createElement('script'); ga.type = 'text/javascript'; ga.async = true;
        ga.src = ('https:' == document.location.protocol ? 'https://ssl' : 'http://www') + '.google-analytics.com/ga.js';
        var s = document.getElementsByTagName('script')[0]; s.parentNode.insertBefore(ga, s);
    })();
</script>